/*
 * SL helps you search for trips with SL, Stockholm's public transport
 * company.  Note that the application is in Swedish.
 *
 *  Copyright (C) 2009  Johan Walles, johan.walles@gmail.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.launchpad.sl;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import android.content.Context;
import android.util.Log;

/**
 * Stream utility methods.
 *
 * @author johan.walles@gmail.com
 */
public class StreamUtil {
    /**
     * Download data from a stream into a private file.
     *
     * @param context An operating system context.
     *
     * @param in The stream to download.  This stream will be closed before this
     * method returns.
     *
     * @param outName Will be passed to
     * {@link Context#openFileOutput(String, int)}.
     *
     * @see Context#openFileInput(String)
     *
     * @throws IOException On trouble downloading the stream.
     */
    public static void download(Context context, InputStream in, String outName)
    throws IOException
    {
        OutputStream out = null;
        try {
            out = context.openFileOutput(outName, Context.MODE_PRIVATE);

            // 25000 is a little bit bigger than the initial answer page
            byte buffer[] = new byte[25000];
            int bytesRead;
            while ((bytesRead = in.read(buffer)) >= 0) {
                out.write(buffer, 0, bytesRead);
            }
        } finally {
            if (in != null) {
                try {
                    in.close();
                } catch (IOException e) {
                    // Closing is a best effort operation, ignore close failures
                    Log.w(SL.TAG, "Failed to close HTML input stream", e);
                }
            }

            if (out != null) {
                try {
                    out.close();
                } catch (IOException e) {
                    // Closing is a best effort operation, ignore close failures
                    Log.w(SL.TAG, "Failed to close HTML output stream", e);
                }
            }
        }
    }
}
