/*
 * SL helps you search for trips with SL, Stockholm's public transport
 * company.  Note that the application is in Swedish.
 *
 *  Copyright (C) 2009  Johan Walles, johan.walles@gmail.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.launchpad.sl.location;

import java.util.Locale;

import android.content.Context;
import android.location.Address;
import android.location.Geocoder;

/**
 * Location utility methods.
 *
 * @author johan.walles@gmail.com
 */
public class LocationUtil {
    /**
     * Return some lines of text describing the given location.
     * @param location The location to describe.
     * @return Some lines of text describing the location.
     */
    public static CharSequence getMultiLineDescription(Address location) {
        StringBuilder description = new StringBuilder(100);
        for (int i = 0; i <= location.getMaxAddressLineIndex(); i++) {
            description.append(location.getAddressLine(i));
            description.append("\n");
        }
        return description;
    }

    /**
     * Return one line of text describing the given location.
     * @param location The location to describe.
     * @return One line of text describing the location.
     */
    public static CharSequence getSingleLineDescription(Address location) {
        if (location.getMaxAddressLineIndex() < 0) {
            return "";
        }
        return location.getAddressLine(0);
    }

    /**
     * Create a geocoder with a Swedish locale.
     *
     * @param context The OS context to pass to
     * {@link Geocoder#Geocoder(Context, Locale)}
     *
     * @return A Swedish speaking geocoder
     */
    public static Geocoder createGeocoder(Context context) {
        Locale swedish = new Locale("sv");
        Geocoder geocoder = new Geocoder(context, swedish);
        return geocoder;
    }
}
