/*
 * SL helps you search for trips with SL, Stockholm's public transport
 * company.  Note that the application is in Swedish.
 *
 *  Copyright (C) 2009  Johan Walles, johan.walles@gmail.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.launchpad.sl.resultsdisplay;

import android.graphics.Canvas;
import android.graphics.Paint;
import com.google.android.maps.MapView;
import com.google.android.maps.Overlay;

/**
 * Draws an X at the center of the map display.
 *
 * @author johan.walles@gmail.com
 */
public class CenterCrossOverlay extends Overlay {
    /**
     * Size of the cross in pixels to go out diagonally in all directions.
     */
    private final static int PIXEL_STEPS = 7;

    /**
     * The color of out X.
     */
    private Paint black;

    /**
     * Create a new CenterCrossOverlay.
     */
    public CenterCrossOverlay() {
        black = new Paint();
        black.setARGB(255, 0, 0, 0);
        black.setStrokeWidth(2);
    }

    @Override
    public void draw(Canvas canvas, MapView map, boolean shadow) {
        if (shadow) {
            return;
        }

        int centerX = map.getWidth() / 2;
        int centerY = map.getHeight() / 2;
        canvas.drawLine(
            centerX - PIXEL_STEPS, centerY - PIXEL_STEPS,
            centerX + PIXEL_STEPS, centerY + PIXEL_STEPS,
            black);
        canvas.drawLine(
            centerX + PIXEL_STEPS, centerY - PIXEL_STEPS,
            centerX - PIXEL_STEPS, centerY + PIXEL_STEPS,
            black);
    }
}
