/*
 * SL helps you search for trips with SL, Stockholm's public transport
 * company.  Note that the application is in Swedish.
 *
 *  Copyright (C) 2009  Johan Walles, johan.walles@gmail.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.launchpad.sl.resultsdisplay;

import net.launchpad.sl.R;
import net.launchpad.sl.RequestKeys;
import net.launchpad.sl.trip.Trip;
import android.app.ListActivity;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.Button;
import android.widget.ListView;

/**
 * Display an overview of the available trips.
 *
 * @author johan.walles@gmail.com
 */
public class DisplayResultDetails extends ListActivity {
    /**
     * Create an intent to display the details of a given trip.
     *
     * @param context The application context.
     *
     * @param trip The trip to show details for.
     *
     * @return An intent to show the details of the given trip.
     */
    public static Intent createDisplayIntent(Context context, Trip trip) {
        Intent intent = new Intent(context, DisplayResultDetails.class);
        intent.putExtra(RequestKeys.TRIP, trip);

        return intent;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        final Trip trip = getIntent().getParcelableExtra(RequestKeys.TRIP);
        setListAdapter(new TripPartsAdapter(trip.getParts(), this));

        setContentView(R.layout.trip_details);
        Button goBackButton =
            (Button)findViewById(R.id.showOverviewButton);
        goBackButton.setOnClickListener(new View.OnClickListener() {
            public void onClick(View v) {
                // Go back to the previous intent
                finish();
            }
        });

        Button showMapButton =
            (Button)findViewById(R.id.showMapButton);
        showMapButton.setOnClickListener(new View.OnClickListener() {
            public void onClick(View v) {
                startActivity(DisplayResultMap.createDisplayIntent(
                    DisplayResultDetails.this, trip));
            }
        });

        ListView list = (ListView)findViewById(android.R.id.list);
        list.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            public void onItemClick(AdapterView<?> arg0, View arg1, int arg2,
                long arg3)
            {
                startActivity(DisplayResultMap.createDisplayIntent(
                    DisplayResultDetails.this, trip));
            }
        });
    }
}
