/*
 * SL helps you search for trips with SL, Stockholm's public transport
 * company.  Note that the application is in Swedish.
 *
 *  Copyright (C) 2009  Johan Walles, johan.walles@gmail.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.launchpad.sl.resultsdisplay;

import net.launchpad.sl.Query;
import net.launchpad.sl.RequestKeys;
import net.launchpad.sl.location.PhoneLocator;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.location.Location;
import android.location.LocationManager;
import android.os.Bundle;
import android.webkit.WebView;
import android.webkit.WebViewClient;

/**
 * Display the result of passing a query to sl.se on a web page.
 *
 * @author johan.walles@gmail.com
 */
public class DisplayResultWeb extends Activity {
    /**
     * The view we use for displaying the sl.se web page.
     */
    private WebView resultDisplay;

    /**
     * Create an intent to display the answer to a given query.
     *
     * @param context The application context.
     *
     * @param query The query to display the answer for.
     *
     * @param location An optional location to use as the current location.
     *
     * @return An intent to show the result for the given query.
     */
    public static Intent createDisplayIntent(Context context,
        Query query, Location location)
    {
        Intent intent = new Intent(context, DisplayResultWeb.class);
        intent.putExtra(RequestKeys.QUERY, query);
        if (location != null) {
            intent.putExtra(RequestKeys.LOCATION, location);
        }

        return intent;
    }

    @Override
    protected void onResume() {
        super.onResume();

        Query query = (Query)getIntent().getParcelableExtra(RequestKeys.QUERY);

        Location location =
            (Location)getIntent().getParcelableExtra(RequestKeys.LOCATION);
        if (location == null) {
            // Use the phone's most recently known location
            LocationManager locationManager =
                (LocationManager)getSystemService(LOCATION_SERVICE);
            PhoneLocator phoneLocator = new PhoneLocator(locationManager);
            location = phoneLocator.getLastKnownLocation();
        }

        resultDisplay.loadUrl(query.toUriString(location, false));
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        resultDisplay = new WebView(this);
        resultDisplay.setWebViewClient(new WebViewClient() {
            @Override
            public void onPageFinished(WebView view, String url) {
                // Scroll the view to the right to get the actual query result
                // into the middle of the screen.  The number of pixels was
                // calibrated on 2009sep30wed.
                view.scrollTo(198, view.getScrollY());
            }
        });

        setContentView(resultDisplay);
    }
}
