/*
 * SL helps you search for trips with SL, Stockholm's public transport
 * company.  Note that the application is in Swedish.
 *
 *  Copyright (C) 2009  Johan Walles, johan.walles@gmail.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.launchpad.sl.resultsdisplay;

import java.util.List;

import net.launchpad.sl.trip.TripPart;
import android.content.Context;
import android.graphics.Typeface;
import android.view.Gravity;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.TextView;

/**
 * Used for displaying {@link TripPart}s in a {@link ListView}.
 *
 * @author johan.walles@gmail.com
 */
public class TripPartsAdapter extends BaseAdapter {
    /**
     * These are the trip parts we're listing.
     */
    private List<TripPart> parts;

    /**
     * Our OS context, used for creating views for the list.
     */
    private Context context;

    /**
     * Construct a new adapter answering a certain query.
     *
     * @param parts The trip parts to display.
     *
     * @param context Used for creating views for the list entries.
     */
    public TripPartsAdapter(List<TripPart> parts, Context context)
    {
        this.parts = parts;
        this.context = context;
    }

    public int getCount() {
        return parts.size();
    }

    public Object getItem(int position) {
        return parts.get(position);
    }

    public long getItemId(int position) {
        return position;
    }

    public View getView(int position, View view, ViewGroup parent) {
        if (view == null) {
            // Top linear layout
            TwoPlusOneLayout top = new TwoPlusOneLayout(context);
            view = top;

            // Left column
            LinearLayout leftColumn = new LinearLayout(context);
            leftColumn.setOrientation(LinearLayout.VERTICAL);
            top.addView(leftColumn);

            // Departure time + station
            TextView text = new TextView(context);
            text.setId(1);
            leftColumn.addView(text);

            // Arrival time + station
            text = new TextView(context);
            text.setId(2);
            leftColumn.addView(text);

            // Transport description
            text = new TextView(context);
            text.setGravity(Gravity.RIGHT);
            text.setId(3);
            top.addView(text);
        }

        TextView fromView = (TextView)view.findViewById(1);
        TextView toView = (TextView)view.findViewById(2);
        TextView descriptionView = (TextView)view.findViewById(3);

        TripPart part = parts.get(position);

        if ("".equals(part.getFromTime())) {
            // The first and the last parts are walking parts, they have no
            // times and should be described differently
            fromView.setText(part.describeTransport()
                + " till " + part.getToStop());
            fromView.setTypeface(Typeface.DEFAULT);

            toView.setText("");
            descriptionView.setText("");
        } else {
            // This part of the trip is using a transport
            fromView.setText(part.getFromTime() + " " + part.getFromStop());
            fromView.setTypeface(Typeface.DEFAULT_BOLD);
            toView.setText(part.getToTime() + " " + part.getToStop());

            descriptionView.setText(part.describeTransport());
        }

        return view;
    }
}
