/*
 * SL helps you search for trips with SL, Stockholm's public transport
 * company.  Note that the application is in Swedish.
 *
 *  Copyright (C) 2009  Johan Walles, johan.walles@gmail.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.launchpad.sl.resultsdisplay;

import android.content.Context;
import android.view.View;
import android.widget.LinearLayout;

/**
 * A horizontal linear layout with two columns.  The left one is two units wide
 * and the right one is one unit wide.
 *
 * @author johan.walles@gmail.com
 */
public class TwoPlusOneLayout extends LinearLayout {
    /**
     * Construct a new layout.
     *
     * @param context The OS context.
     */
    public TwoPlusOneLayout(Context context) {
        super(context);
    }

    @Override
    public int getOrientation() {
        return LinearLayout.HORIZONTAL;
    }

    @Override
    protected void onLayout(boolean changed,
        int left, int top, int right, int bottom)
    {
        int childCount = getChildCount();
        if (childCount != 2) {
            throw new IllegalStateException("Must have exactly two children, have " + childCount);
        }

        int twoThirds = (getMeasuredWidth() * 2) / 3;
        for (int i = 0; i < childCount; i++) {
            View child = getChildAt(i);

            switch (i) {
            case 0:
                child.layout(0, 0, twoThirds - 1, getMeasuredHeight() - 1);
                break;

            case 1:
                child.layout(twoThirds, 0,
                    getMeasuredWidth() - 1, getMeasuredHeight() - 1);
                break;
            }
        }
    }

    @Override
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        if (MeasureSpec.getMode(widthMeasureSpec) == MeasureSpec.UNSPECIFIED) {
            throw new IllegalArgumentException("Must get a specific width, was UNSPECIFIED");
        }

        int childCount = getChildCount();
        if (childCount != 2) {
            throw new IllegalStateException("Must have exactly two children, have " + childCount);
        }

        int width = MeasureSpec.getSize(widthMeasureSpec);
        int twoThirds = (width * 2) / 3;
        int oneThird = width - twoThirds;
        for (int i = 0; i < childCount; i++) {
            View child = getChildAt(i);

            switch (i) {
            case 0:
                child.measure(
                    MeasureSpec.makeMeasureSpec(twoThirds, MeasureSpec.EXACTLY),
                    heightMeasureSpec);
                break;

            case 1:
                child.measure(
                    MeasureSpec.makeMeasureSpec(oneThird, MeasureSpec.EXACTLY),
                    heightMeasureSpec);
                break;
            }
        }

        int height =
            Math.max(getChildAt(0).getMeasuredHeight(),
                getChildAt(1).getMeasuredHeight());

        setMeasuredDimension(width, height);
    }
}
