/*
 * SL helps you search for trips with SL, Stockholm's public transport
 * company.  Note that the application is in Swedish.
 *
 *  Copyright (C) 2009  Johan Walles, johan.walles@gmail.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.launchpad.sl;

import junit.framework.TestCase;

/**
 * Verify the functionality of the {@link LocationSelectionAdapter}.
 *
 * @author johan.walles@gmail.com
 */
public class TestLocationSelectionAdapter extends TestCase {
    /**
     * Verify {@link LocationSelectionAdapter#streetify(String)}
     */
    public void testStreetify() {
        // With space
        assertEquals("Barks väg",
            LocationSelectionAdapter.streetify("Barks väg 6"));

        // Strip street number
        assertEquals("Åsögatan",
            LocationSelectionAdapter.streetify("Åsögatan 90"));

        // Strip street number++
        assertEquals("Åsögatan",
            LocationSelectionAdapter.streetify("Åsögatan 90b"));

        // Strip city
        assertEquals("Åsögatan",
            LocationSelectionAdapter.streetify("Åsögatan 90\nStockholm"));

        // Strip city
        assertEquals("Åsögatan",
            LocationSelectionAdapter.streetify("Åsögatan 90, Stockholm"));

        // No street number
        assertNull("A place without a street number shouldn't count as a street",
            LocationSelectionAdapter.streetify("Medborgarplatsen"));
        assertNull(LocationSelectionAdapter.streetify("Medborgarplatsen\nStockholm"));
        assertNull(LocationSelectionAdapter.streetify("Medborgarplatsen, Stockholm"));
    }
}
