/*
 * SL helps you search for trips with SL, Stockholm's public transport
 * company.  Note that the application is in Swedish.
 *
 *  Copyright (C) 2009  Johan Walles, johan.walles@gmail.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.launchpad.sl.trip;

import java.util.Arrays;
import java.util.List;

import net.launchpad.sl.Query;
import net.launchpad.sl.location.NamedLocation;

import android.os.Parcel;
import junit.framework.TestCase;

/**
 * Verify {@link Trip}.
 *
 * @author johan.walles@gmail.com
 */
public class TestTrip extends TestCase {
    /**
     * Verify constructor.
     */
    public void testTrip() {
        NamedLocation from = new NamedLocation("Åsögatan 90", 59, 17, "Hemma");
        NamedLocation to = new NamedLocation("Barks väg 6", 58, 18, "Mamma");
        Query query = new Query(from, to);

        Trip trip =
            new Trip(query, null, null, null, null, 0, 0, null, "C0-0", null);
        assertEquals(query, trip.getQuery());
        assertEquals(0x000000, trip.getId());

        trip = new Trip(null, null, null, null, null, 0, 0, null, "C10-11", null);
        assertEquals(0x0a000b, trip.getId());
    }

    /**
     * Verify parceling of the given trip.
     *
     * @param parcelMe The trip we should try to parcel.
     */
    private void testParceling(Trip parcelMe) {
        // Verify that this test is up to date with the Trip class
        assertEquals(14, Trip.class.getDeclaredFields().length);

        // Marshall
        Parcel parcel = Parcel.obtain();
        parcelMe.writeToParcel(parcel, 0);
        byte marshalled[] = parcel.marshall();
        parcel.recycle();

        // Unmarshall
        parcel = Parcel.obtain();
        parcel.unmarshall(marshalled, 0, marshalled.length);
        parcel.setDataPosition(0);
        Trip parcelled = Trip.CREATOR.createFromParcel(parcel);
        parcel.recycle();

        assertEquals(parcelMe.getArrivalTime(), parcelled.getArrivalTime());
        assertEquals(parcelMe.getChanges(), parcelled.getChanges());
        assertEquals(parcelMe.getDepartureTime(), parcelled.getDepartureTime());
        assertEquals(parcelMe.getDurationMinutes(), parcelled.getDurationMinutes());
        assertEquals(parcelMe.getEndMapUrl(), parcelled.getEndMapUrl());
        assertEquals(parcelMe.getFirstStop(), parcelled.getFirstStop());
        assertEquals(parcelMe.getId(), parcelled.getId());
        assertEquals(parcelMe.getLastStop(), parcelled.getLastStop());
        assertEquals(parcelMe.getStartMapUrl(), parcelled.getStartMapUrl());
        assertEquals(parcelMe.getParts(), parcelled.getParts());
        assertEquals(parcelMe.getTransports(), parcelled.getTransports());
        assertEquals(parcelMe.getQuery(), parcelled.getQuery());
    }

    /**
     * Verify that parceling works.
     */
    public void testParceling() {
        List<String> transports =
            Arrays.asList(new String[] { "bil", "båt", "häst+vagn" });
        NamedLocation from = new NamedLocation("Åsögatan 90", 59, 17, "Hemma");
        NamedLocation to = new NamedLocation("Barks väg 6", 58, 18, "Mamma");
        Query query = new Query(from, to);
        Trip tryMe =
            new Trip(query,
                "from", "to",
                "03:15", "09:20",
                42, 9,
                transports,
                "C1-2", "http://gris");
        List<TripPart> tripParts =
            Arrays.asList(new TripPart[] {
                new TripPart("pfrom", "pto",
                    "04:30", "05:30",
                    "ptransport", "pjättefort")
            });
        tryMe.setParts(tripParts);
        testParceling(tryMe);
    }
}
