/*
 * SL helps you search for trips with SL, Stockholm's public transport
 * company.  Note that the application is in Swedish.
 *
 *  Copyright (C) 2009  Johan Walles, johan.walles@gmail.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.launchpad.sl.trip;

import junit.framework.TestCase;

/**
 * Verify {@link TripPart} functionality.
 *
 * @author johan.walles@gmail.com
 */
public class TestTripPart extends TestCase {
    /**
     * Verify that {@link TripPart#describeTransport()} properly converts the
     * given transport and details into a description string.
     *
     * @param transport The transport to describe.
     *
     * @param details Details about the transport.
     *
     * @param expectedDescription The expected description of this transport and
     * its details.
     */
    private void verifyTransform(String transport, String details,
        String expectedDescription)
    {
        assertEquals(expectedDescription,
            new TripPart(null, null, null, null,
                transport, details).describeTransport().toString());
    }

    /**
     * Verify {@link TripPart#describeTransport()}.
     */
    public void testDescribeTransport() {
        // Naive fallback for stuff we cannot parse
        verifyTransform("apskaft", "grishej", "Apskaft grishej");
        verifyTransform("Apskaft", "Grishej", "Apskaft grishej");

        // Walk
        verifyTransform("Gå", "Cirka 900 meter",
            "Gå cirka 900 meter");

        // Use some transport
        verifyTransform("tunnelbanans röda linje 13", "mot: Ropsten",
            "Tunnelbanans röda linje 13 mot Ropsten");
        verifyTransform("pendeltåg 36", "mot: Märsta",
            "Pendeltåg 36 mot Märsta");
        verifyTransform("blåbuss 178", "mot: Jakobsbergs station",
            "Blåbuss 178 mot Jakobsbergs station");
        verifyTransform("Roslagsbanan 28", "mot: Stockholms östra",
            "Roslagsbanan 28 mot Stockholms östra");
        verifyTransform("Saltsjöbanan 25", "mot: Saltsjöbaden",
            "Saltsjöbanan 25 mot Saltsjöbaden");
        verifyTransform("Tvärbanan 22", "mot: Sickla udde",
            "Tvärbanan 22 mot Sickla udde");
        verifyTransform("Nockebybanan 12", "mot: Alvik",
            "Nockebybanan 12 mot Alvik");
    }
}
